#ifndef __AMSSTRING4_TESTS_HPP__
#define __AMSSTRING4_TESTS_HPP__

namespace ams
{

    void amsstring4_basic_string_test1();
    void amsstring4_sscanf_test1();
    void amsstring4_basic_string_test2();
    void amsstring4_memoryleakcheck1();
    void amsstring4_memoryleakcheck2();
    void amsstring4_stringtests2();
    void amsstring4_test_find();

    void amsstring4_test_splitlines();
    void amsstring4_test_split();
    void amsstring4_test_strip();
    void amsstring4_test_freadwrite();

    void amsstring4_test_concatenation_operators();
    
    void amsstring4_test_convenience1a();
    void amsstring4_test_convenience1b();
    void amsstring4_test_convenience1c();

};

#endif

