#include <amsstring4/amsstring4.hpp>

using namespace ams;

int main(int argc, char* argv[])
{
    int ret = 0;
    printf("ams string4 library tests.\n");

    // amsstring4_basic_string_test1();
    // amsstring4_sscanf_test1();
    // amsstring4_basic_string_test2();
    // amsstring4_memoryleakcheck1();
    // amsstring4_memoryleakcheck2();
    // amsstring4_stringtests2();
    // amsstring4_test_find();

    // amsstring4_test_splitlines();
    // amsstring4_test_split();
    // amsstring4_test_strip();
    // amsstring4_test_freadwrite();

    // amsstring4_test_concatenation_operators(); 

    //amsstring4_test_convenience1a();
    //amsstring4_test_convenience1b();
    amsstring4_test_convenience1c();
    
    return ret;
}